Welcome to pkgdev's documentation!
==================================

Contents:

.. toctree::
    :titlesonly:
    :maxdepth: 4

    man/pkgdev

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
